@@ -47,7 +47,7 @@
 #include "rdkafka.h"  /* for Kafka driver */
 
 
-static int run = 1;
+static volatile sig_atomic_t run = 1;
 static rd_kafka_t *rk;
 static int exit_eof = 0;
 static int quiet = 0;
@@ -524,7 +524,7 @@ int main (int argc, char **argv) {
 			"  -p <num>        Partition (random partitioner)\n"
 			"  -b <brokers>    Broker address (localhost:9092)\n"
 			"  -z <codec>      Enable compression:\n"
-			"                  none|gzip|snappy\n"
+			"                  none|gzip|snappy|lz4|zstd\n"
 			"  -o <offset>     Start offset (consumer):\n"
 			"                  beginning, end, NNNNN or -NNNNN\n"
 			"                  wmark returns the current hi&lo "
